@@ -1,13 +1,13 @@
 class ADSLData:
-    service_type = 'adsl'
+    type = 'adsl'
 
     def __init__(
-            self, order_id, phone_number, iban, email,
-            landline_phone_number, service_address, service_city, service_zip,
-            service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
-            shipment_subdivision, previous_service, previous_provider, previous_internal_provider,
-            previous_owner_vat, previous_owner_name, previous_owner_surname, notes,
-            adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, type, product,
+        self, order_id, phone_number, iban, email,
+        landline_phone_number, service_address, service_city, service_zip,
+        service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
+        shipment_subdivision, previous_service, previous_provider, previous_internal_provider,
+        previous_owner_vat, previous_owner_name, previous_owner_surname, notes,
+            adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, change_address, product,
             previous_contract_address="", previous_contract_phone=""):
         # Common all the Tickets
         self.order_id = order_id
@@ -35,7 +35,7 @@ class ADSLData:
         self.adsl_coverage = adsl_coverage
         self.mm_fiber_coverage = mm_fiber_coverage
         self.vdf_fiber_coverage = vdf_fiber_coverage
-        self.type = type
+        self.change_address = change_address
         self.previous_contract_address = previous_contract_address
         self.previous_contract_phone = previous_contract_phone
 
