@@ -42,7 +42,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
 
     def _previous_provider(self):
         provider = None
-        if self.service_data.type != "location_change":
+        if self.service_data.change_address == "no":
             provider = self.service_data.previous_provider
         return DynamicField(name="proveidorPrevi", value=provider)
 
@@ -101,10 +101,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
         return DynamicField(name="direccioServeiAntic", value=self.service_data.previous_contract_address)
 
     def _change_address(self):
-        change_address = None
-        if self.service_data.type == "location_change":
-            change_address = "location_change"
-        return DynamicField(name="canviUbicacioMateixTitular", value=change_address)
+        return DynamicField(name="canviUbicacioMateixTitular", value=self.service_data.change_address)
 
     def _change_address_provider(self):
         return DynamicField(name="proveidorPreviCU", value=self.service_data.previous_internal_provider)
