@@ -1,9 +1,9 @@
 class MobileData:
-    service_type = 'mobile'
+    type = 'mobile'
 
     def __init__(
         self, order_id, phone_number, iban, email, sc_icc, icc,
-        portability, previous_owner_vat, previous_owner_name,
+        has_sim, portability, previous_owner_vat, previous_owner_name,
         previous_owner_surname, previous_provider, product, notes=""
     ):
         self.order_id = order_id
@@ -13,6 +13,7 @@ class MobileData:
         self.sc_icc = sc_icc
         self.icc = icc
         self.portability = portability
+        self.has_sim = has_sim
         self.previous_provider = previous_provider
         self.previous_owner_vat = previous_owner_vat
         self.previous_owner_name = previous_owner_name
