@@ -26,6 +26,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'previous_owner_vat',
             'product',
             'notes',
+            'has_sim',
         ])
         customer_data = Mock(spec=[
             'id',
@@ -38,7 +39,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'zip',
             'subdivision'])
 
-        mobile_data.service_type = 'mobile'
+        mobile_data.type = 'mobile'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -84,14 +85,14 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'type',
+            'change_address',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.service_type = 'adsl'
+        service_data.type = 'adsl'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -140,12 +141,13 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
+            'change_address',
             'product',
             'previous_internal_provider',
         ])
         customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
-        service_data.service_type = 'fiber'
+        service_data.type = 'fiber'
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
