@@ -50,7 +50,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'type',
+            'change_address',
             'product',
             'previous_internal_provider',
         ])
@@ -184,6 +184,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "Nubip"
+        self.service_data.change_address = "no"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
@@ -404,6 +405,19 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
 
+    def test_change_address_field(self):
+        self.service_data.change_address = "yes"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
+
 # Service Dynamic Fields
     def test_landline_number_field(self):
         self.service_data.landline_phone_number = "666666666"
@@ -445,7 +459,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
     def test_previous_provider_not_exists_in_change_address(self):
-        self.service_data.type = 'location_change'
+        self.service_data.change_address = True
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
