@@ -95,7 +95,7 @@ class ADSLTicketTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'type',
+            'change_address',
             'landline_phone_number',
             'product',
             'previous_internal_provider',
