@@ -31,7 +31,7 @@ class FiberDataTestCase(unittest.TestCase):
             adsl_coverage=None,
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
-            type="new",
+            change_address="no",
             product="product",
             previous_contract_address="Old street",
             previous_contract_phone="62626826",
