@@ -51,9 +51,10 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'type',
+            'change_address',
             'product',
             'previous_internal_provider',
+            'change_address',
         ])
 
         self.adsl_otrs_process_id = "ADSLProcessID"
@@ -114,7 +115,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(
-            dynamic_fields_dct["IDtryton"],
+            dynamic_fields_dct["ponAntic"],
             self.service_data.previous_contract_pon
         )
 
@@ -250,6 +251,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "SomConnexio"
+        self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -469,6 +471,36 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
 
+    def test_change_address_field(self):
+        self.service_data.change_address = "yes"
+        self.service_data.previous_owner_name = "A"
+        self.service_data.previous_owner_surname = "B"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
+        self.assertEqual(dynamic_fields_dct["nomCognomSociAntic"], "A B")
+
+    def test_change_address_field_not_set(self):
+        self.service_data.change_address = "no"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
+        self.assertFalse(dynamic_fields_dct.get("nomCognomSociAntic"))
+
     def test_product_field(self):
         self.service_data.product = "FIBRA100"
 
@@ -496,7 +528,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
     def test_previous_provider_not_exists_in_change_address(self):
-        self.service_data.type = 'location_change'
+        self.service_data.change_address = True
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
