@@ -97,9 +97,10 @@ class FiberTicketTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
-            'type',
+            'change_address',
             'product',
             'previous_internal_provider',
+            'change_address',
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
