@@ -85,7 +85,7 @@ class MobileTicketTestCase(unittest.TestCase):
             'previous_owner_surname',
             'product',
             'notes',
-            'type',
+            'has_sim',
         ])
         mobile_data.order_id = 4321
         mobile_data.portability = False
